@@ -76,6 +76,8 @@ void eWallet::showList () {
 		// Custom list box
 
 		fnListWidget = new QListWidget(this);
+		fnListWidget->setSortingEnabled(false);
+		//fnListWidget->setSortingEnabled(false);
 		vboxlayout->addWidget(fnListWidget);
 
 		QObject::connect(fnListWidget, SIGNAL(itemClicked(QListWidgetItem *)), this, SLOT(selectItem(QListWidgetItem *)));
@@ -493,6 +495,20 @@ bool eWallet::_insertTarget(Target* target)
 }
 bool eWallet::_deleteTarget(Target* target)
 {
+	if (messageBox.isNull()) {
+		messageBox = new QMessageBox(this);
+		int b = messageBox->information(this, "Wallet", "Are you sure you want to remove it?", QMessageBox::Yes, QMessageBox::No);
+		if (b != QMessageBox::Yes) {
+			delete messageBox;
+			messageBox = 0;
+
+			return false;
+		}
+	}
+	delete messageBox;
+	messageBox = 0;
+
+
 	int i = list.indexOf(target);
 	//qDebug () << "DELETE ON " << i;
 	if (::dbManager->deleteTarget(target)) {
@@ -545,14 +561,9 @@ bool eWallet::_updateTargetPictureBack(Target* target)
 }
 
 void eWallet::deleteTarget(Target * target) {
-
-	//qDebug()<<"delete ";
-
-	//row = fnListWidget->findRow(target);
-	
-	_deleteTarget (target);
-
-	delete target;
+	if (_deleteTarget (target)) {
+		delete target;
+	}
 }
 
 void eWallet::windowDestroyed(QObject* obj)
@@ -839,7 +850,9 @@ void eWallet::askPassword () {
 
 		// TODO should I remove all included widgets??
 		setCentralWidget(loginDialogDlg);
-		loginDialogDlg->setFocus ();
+		//show ();
+		setFocus ();
+		focusNextChild();
 
 //		centralWidget = NULL;
 //		vboxlayout = NULL;
