@@ -53,6 +53,7 @@ private:
 	void loadTypesAndFields ();
 	void filterBy (const QString & s);
 	QPixmap getImage (Target * f);
+	bool isAskPassword;
 
 private slots:
     void windowDestroyed(QObject* obj = 0);
@@ -67,9 +68,9 @@ private slots:
 	void import();
 	void exportData();
 	void textChanged (const QString &);
+	void contextMenuEvent (QContextMenuEvent * event);
 	
 private:
-
 	void askPassword ();
 	void closeEvent(QCloseEvent *event);
 	
